import { useState, useCallback, useLayoutEffect } from "react";

function getDimensionObject(node) {
    var rect = node.getBoundingClientRect();

    if (rect.toJSON) {
        return rect.toJSON();
    } else {
        return {
            width: rect.width,
            height: rect.height,
            top: rect.top || rect.x,
            left: rect.left || rect.left,
            x: rect.x || rect.left,
            y: rect.y || rect.top,
            right: rect.right,
            bottom: rect.bottom
        };
    }
}

function useDimensions() {
    var _useState = useState({}),
        dimensions = _useState[0],
        setDimensions = _useState[1];

    var _useState2 = useState(null),
        node = _useState2[0],
        setNode = _useState2[1];

    var ref = useCallback(function (node) {
        setNode(node);
    }, []);

    useLayoutEffect(function () {
        if (node) {
            var measure = function measure() {
                return window.requestAnimationFrame(function () {
                    return setDimensions(getDimensionObject(node));
                });
            };
            measure();

            window.addEventListener("resize", measure);
            window.addEventListener("scroll", measure);

            return function () {
                window.removeEventListener("resize", measure);
                window.removeEventListener("scroll", measure);
            };
        }
    }, [node]);

    return [ref, dimensions, node];
}

export default useDimensions;